@@ -523,7 +523,11 @@ end
 
 
 ## world view of the cache
-using Core.Compiler: WorldView
+if !isdefined(CC, :WorldView)
+    using Core.Compiler: InternalCodeCache as WorldView
+else
+    using Core.Compiler: WorldView
+end
 
 if !HAS_INTEGRATED_CACHE
 
